GLaDOS Package
==============

.. automodule:: glados
   :members:
   :undoc-members:
   :show-inheritance:



Modules
-------
.. toctree::
   :maxdepth: 7

   glados.bot
   glados.configs
   glados.core
   glados.datastore
   glados.errors
   glados.message_blocks
   glados.plugin
   glados.request
   glados.route_type
   glados.router
   glados.utils
